@@ -1,14 +1,88 @@
+use strict;
+use warnings;
+
+package Params::Callbacks;
+our $VERSION = '2.0.31'; # VERSION
+# ABSTRACT: Enable subroutines to accept optional blocking callbacks easily
+use Exporter ();
+use Scalar::Util ( 'blessed' );
+use namespace::clean;
+use constant CALLBACK_CLASS => 'Params::Callbacks::Callback';
+use Message::String << 'EOF';
+CRIT_BAD_CALLBACK_LIST First argument must be a %s object
+EOF
+
+our @ISA         = ( 'Exporter' );
+our @EXPORT_OK   = ( 'callbacks', 'callback' );
+our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
+
+sub new
+{
+    my ( $class, @params ) = @_;
+    # Recycle a callback chain if that's what was passed
+    if ( blessed( $params[-1] ) && $params[-1]->isa( __PACKAGE__ ) ) {
+        my $callback_chain = pop @params;
+        return $callback_chain, @params;
+    }
+    # Build a new callback chain.
+    my @callbacks;
+    while (    @params
+            && blessed( $params[-1] )
+            && $params[-1]->isa( CALLBACK_CLASS ) )
+    {
+        unshift @callbacks, pop @params;
+    }
+    return bless( \@callbacks, $class ), @params;
+}
+
+sub transform
+{
+    my ( $callbacks, @data ) = @_;
+    CRIT_BAD_CALLBACK_LIST( __PACKAGE__ )
+        unless ref( $callbacks ) && $callbacks->isa( __PACKAGE__ );
+    for my $callback ( @$callbacks ) {
+        last unless @data;
+        @data = map { $callback->( $_ ) } @data;
+    }
+    return @data;
+}
+
+sub smart_transform
+{
+    # Transform the data (use same @_)
+    my @data = &transform;
+    # If only a single element exists in @data then return *that* element
+    # when in scalar context; don't return an element count. At all other
+    # times, subject @data to normal array semantics.
+    return @data if wantarray;
+    return scalar( @data ) if @data != 1;
+    return $data[0];
+}
+
+sub callbacks
+{
+    return __PACKAGE__->new( @_ );
+}
+
+sub callback (&;@)
+{
+    my ( $callback, @params ) = @_;
+    return bless( $callback, CALLBACK_CLASS ), @params;
+}
+
+1;
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Params::Callbacks - Make your subroutines accept blocking callbacks
+Params::Callbacks - Enable subroutines to accept blocking callbacks easily
 
 =head1 VERSION
 
-version 2.0.30
+version 2.0.31
 
 =head1 SYNOPSIS
 
@@ -159,27 +233,8 @@ chain is terminated for that value.
     #
     # (Moar awesome!)
 
-=cut
-
-use strict;
-use warnings;
-
-package Params::Callbacks;
-our $VERSION = '2.0.30'; # VERSION
-# ABSTRACT: Use to enable subroutines to accept optional blocking callbacks. 
-use Exporter ();
-use Scalar::Util qw(blessed);
-use Carp qw(confess);
-use namespace::clean;
-
-our @ISA         = qw(Exporter);
-our @EXPORT_OK   = qw(callbacks callback);
-our %EXPORT_TAGS = ( all => \@EXPORT_OK, ALL => \@EXPORT_OK );
-
 =head1 METHODS
 
-=cut
-
 =head2 new
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
@@ -203,33 +258,6 @@ nested call is required.
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
-=cut
-
-
-sub new
-{
-    my ( $class, @params ) = @_;
-    my @callbacks;
-
-    if ( blessed( $params[-1] ) ) {
-        if ( $params[-1]->isa(__PACKAGE__) ) {
-            my $callback_chain = pop(@params);
-            return ( bless( $callback_chain, $class ), @params );
-        }
-        else {
-            while (    @params
-                    && blessed( $params[-1] )
-                    && $params[-1]->isa('Params::Callbacks::Callback') )
-            {
-                unshift @callbacks, pop(@params);
-            }
-
-        }
-    }
-
-    return ( bless( \@callbacks, $class ), @params );
-}
-
 =head2 transform
 
 Transform a result set by passing it through all the stages of the callbacks
@@ -238,25 +266,6 @@ nothing, and an empty result set is returned.
 
 Empty or not, this method always returns a list.
 
-=cut
-
-
-sub transform
-{
-    my ( $callbacks, @data ) = @_;
-
-    confess 'E-PARAMS-CALLBACKS-001 Expected Params::Callbacks object reference '
-      . 'as first argument'
-      unless ref($callbacks) && $callbacks->isa(__PACKAGE__);
-
-    for my $callback (@$callbacks) {
-        last unless @data;
-        @data = map { $callback->($_) } @data;
-    }
-
-    return @data;
-}
-
 =head2 smart_transform
 
 Transform a result set by passing it through all the stages of the callbacks
@@ -269,29 +278,6 @@ If a scalar is required, a scalar is returned. If the result set contains a
 single element then the value of that element will be returned, otherwise a
 count of the number of elements is returned.
 
-=cut
-
-
-sub smart_transform
-{
-    my @data = &transform;
-
-    unless (wantarray) {
-        my $result;
-
-        if ( @data != 1 ) {
-            $result = scalar(@data);
-        }
-        else {
-            $result = $data[0];
-        }
-
-        return $result;
-    }
-
-    return @data;
-}
-
 =head1 EXPORTS
 
 Nothing is exported by default.
@@ -299,8 +285,6 @@ Nothing is exported by default.
 The following functions are exported individually upon request; they may all be
 imported at once using the import tags C<:all> and C<:ALL>.
 
-=cut
-
 =head2 callbacks
 
 Takes a list of scalar values, strips away any trailing callbacks and returns
@@ -329,14 +313,6 @@ more deeply nested call.
 The output list is packaged in such a way as to make parsing the argument list
 as easy as possible.
 
-=cut
-
-
-sub callbacks
-{
-    return __PACKAGE__->new(@_);
-}
-
 =head2 callback
 
 A simple piece of syntactic sugar that announces a callback. The code
@@ -350,17 +326,6 @@ separators:
     callback { ... }, callback { ... }, callback { ... }    # Valid
     callback { ... }  callback { ... }  callback { ... }    # Valid, too!
 
-=cut
-
-
-sub callback (&;@)
-{
-    my ( $callback, @params ) = @_;
-    return ( bless( $callback, 'Params::Callbacks::Callback' ), @params );
-}
-
-1;
-
 =head1 REPOSITORY
 
 =over 2
